svn commit: r187398 - in stable/7/sys: . arm/at91 contrib/pf dev/ath/ath_hal dev/cxgb

Stanislav Sedov stas at FreeBSD.org
Sun Jan 18 09:07:49 PST 2009


Author: stas
Date: Sun Jan 18 17:07:48 2009
New Revision: 187398
URL: http://svn.freebsd.org/changeset/base/187398

Log:
  - MFC r182524 and r182555:
    - Set U/L bit in generate MAC address.
    - Use our specific OUI instead of Atmel one.

Modified:
  stable/7/sys/   (props changed)
  stable/7/sys/arm/at91/if_ate.c
  stable/7/sys/contrib/pf/   (props changed)
  stable/7/sys/dev/ath/ath_hal/   (props changed)
  stable/7/sys/dev/cxgb/   (props changed)

Modified: stable/7/sys/arm/at91/if_ate.c
==============================================================================
--- stable/7/sys/arm/at91/if_ate.c	Sun Jan 18 15:10:46 2009	(r187397)
+++ stable/7/sys/arm/at91/if_ate.c	Sun Jan 18 17:07:48 2009	(r187398)
@@ -193,19 +193,21 @@ ate_attach(device_t dev)
 
 	if ((err = ate_get_mac(sc, eaddr)) != 0) {
 		/*
 		 * No MAC address configured. Generate the fake one.
 		 */
 		if  (bootverbose)
 			device_printf(dev,
-			    "Generating fake ethernet address.\n");
+			    "Generating random ethernet address.\n");
 		rnd = arc4random();
 
 		/*
-		 * Set OUI to Atmel.
+		 * Set OUI to convenient locally assigned address.  'b'
+		 * is 0x62, which has the locally assigned bit set, and
+		 * the broadcast/multicast bit clear.
 		 */
-		eaddr[0] = 0x00;
-		eaddr[1] = 0x04;
-		eaddr[2] = 0x25;
+		eaddr[0] = 'b';
+		eaddr[1] = 's';
+		eaddr[2] = 'd';
 		eaddr[3] = (rnd >> 16) & 0xff;
 		eaddr[4] = (rnd >> 8) & 0xff;
 		eaddr[5] = rnd & 0xff;
@@ -193,19 +193,21 @@ ate_attach(device_t dev)
 	if ((err = ate_get_mac(sc, eaddr)) != 0) {
 		/*
-		 * No MAC address configured. Generate the fake one.
+		 * No MAC address configured. Generate the random one.
 		 */
 		if  (bootverbose)


More information about the svn-src-stable-7 mailing list